Changelog
---------

2.1.0 (2020-12-14)
~~~~~~~~~~~~~~~~~~

* Make token expiry optional from the authentication server.

* Added optional token_url parameter for when the AuthenticatedSession is 
  used for non-Trioptima authentication servers.


2.0.0 (2019-12-03)
~~~~~~~~~~~~~~~~~~

* Change import path from tri.event to tri_event to conform to other packages.
  (And increase import time performance during test setup)


1.0.1 (2019-09-02)
~~~~~~~~~~~~~~~~~~

* Improve documentation

1.0.0 (2019-05-10)
~~~~~~~~~~~~~~~~~~

* Make an authentication retry if unauthorized to improve robustness
* Update status to production ready


0.0.7 (2019-03-22)
~~~~~~~~~~~~~~~~~~

* Use configured proxy and timeouts also for authentication
* Delay authentication until first request is made


0.0.6 (2019-02-18)
~~~~~~~~~~~~~~~~~~

* Change base class of EventSession to request.Session


.0.5 (2019-01-22)
~~~~~~~~~~~~~~~~~~

* Fix packaging

* Add EventSession.access_token and EventSession.token_expiry attributes


0.0.4 (2019-01-21)
~~~~~~~~~~~~~~~~~~

* Cleanup of logging


0.0.3 (2019-01-10)
~~~~~~~~~~~~~~~~~~

* Add session renewal on access token expiry

* Improve exception on failure to log in


0.0.2 (2018-12-20)
~~~~~~~~~~~~~~~~~~

* Initial version
